# VqePy

## Installation

VqePy requires Python 3.9 or newer.

To install VqePy on macOS or Linux, open a terminal and run:
```Shell
python -m pip install vqepy
```



## Tesis project
This library was a project to get a degree in computer science in the UTFSM University.

The main idea is implement a few variational quantum algorithms to study condensed matter and chemistry models and give a basic template to study complex phenomena. This project didnt want to be another quantum library. This should be see as a high level implementation to study systems with a fixed route to be executed, so, the user only need to give the parameters and just the minimun programming is needed (in the demo it's possible to see the code structure). 